@@ -4,7 +4,7 @@
  * including the overlaps integrals between different geometries
  * And the dipoles and quadrupoles to compute absorption spectra.
  * This module is based on libint, Eigen and pybind11.
- * Copyright (C) 2018-2020 the Netherlands eScience Center.
+ * Copyright (C) 2018-2022 the Netherlands eScience Center.
  */
 #include "namd.hpp"
 
@@ -12,10 +12,12 @@ namespace py = pybind11;
 using HighFive::Attribute;
 using HighFive::DataSet;
 using HighFive::File;
+using HighFive::Group;
 using libint2::Atom;
 using libint2::BasisSet;
 using libint2::Operator;
 using libint2::Shell;
+using namd::CP2K_Contractions;
 using namd::CP2K_Basis_Atom;
 using namd::map_elements;
 using namd::valence_electrons;
@@ -80,20 +82,33 @@ template <typename Lambda> void parallel_do(Lambda &lambda) {
  * \brief Set the number of thread to use
  */
 void set_nthread() {
-
+#if defined(_OPENMP)
   using libint2::nthreads;
   nthreads = std::thread::hardware_concurrency();
-
-#if defined(_OPENMP)
   omp_set_num_threads(nthreads);
 #endif
-  std::cout << "Will scale over " << nthreads
-#if defined(_OPENMP)
-            << " OpenMP"
-#else
-            << " C++11"
-#endif
-            << " threads" << std::endl;
+}
+
+/**
+ * \brief Get the number of threads and the thread type as a 2-tuple
+ */
+int get_thread_count() {
+  using libint2::nthreads;
+  return std::thread::hardware_concurrency();
+}
+
+/**
+ * \brief Get the type of threads
+ */
+string get_thread_type() {
+  string ret;
+
+  #if defined(_OPENMP)
+    ret = "OpenMP";
+  #else
+    ret = "C++11";
+  #endif
+  return ret;
 }
 
 /**
@@ -279,67 +294,88 @@ std::vector<Matrix> compute_multipoles(
   return result;
 }
 
-libint2::svector<int> read_basisFormat(const string &basisFormat) {
-  // Transform the string containing the basis format for CP2K, into a vector of
-  // strings
-  libint2::svector<int> rs;
-  for (auto x : basisFormat) {
-    if (std::isdigit(x))
-      // convert char to int
-      rs.push_back(x - '0');
-  }
-  return rs;
-}
-
 /**
  * \brief Read a basis set from HDF5 as a matrix
  */
 CP2K_Basis_Atom read_basis_from_hdf5(const string &path_file,
                                      const string &symbol,
                                      const string &basis) {
-  std::vector<std::vector<double>> coefficients;
-  std::vector<double> exponents;
-  string format;
-  try {
+  libint2::svector<libint2::svector<double>> small_exp;
+  libint2::svector<libint2::svector<double>> small_coef;
+  libint2::svector<libint2::svector<CP2K_Contractions>> small_fmt;
 
+  try {
     // Open an existing HDF5 File
-    File file(path_file, File::ReadOnly);
+    const File file(path_file, File::ReadOnly);
 
     // build paths to the coefficients and exponents
-    int n_elec = valence_electrons.at(symbol);
-    string root = "cp2k/basis/" + symbol + "/" + basis + "-q" + std::to_string(n_elec);
-    string path_coefficients = root + "/coefficients";
-    string path_exponents = root + "/exponents";
+    const int n_elec = valence_electrons.at(symbol);
+    const string root = "cp2k/basis/" + symbol + "/" + basis + "-q" + std::to_string(n_elec);
 
-    // Get the dataset
-    DataSet dataset_cs = file.getDataSet(path_coefficients);
-    DataSet dataset_es = file.getDataSet(path_exponents);
-    Attribute attr = dataset_cs.getAttribute("basisFormat");
+    const Group group = file.getGroup(root);
+    const std::vector<string> dset_names = group.listObjectNames();
 
-    // extract data from the
-    dataset_cs.read(coefficients);
-    dataset_es.read(exponents);
-    attr.read(format);
+    // Iterate over all exponent sets; for most basis sets there is
+    // only a single set of exponents, but there are exception such
+    // as BASIS_ADMM_MOLOPT
+    for (const auto &name : dset_names) {
+      std::vector<std::vector<double>> coefficients;
+      std::vector<double> exponents;
+      std::vector<int64_t> format;
 
+      const string path_coefficients = root + "/" + name + "/coefficients";
+      const string path_exponents = root + "/" + name + "/exponents";
+
+      // Get the dataset
+      const DataSet dataset_cs = file.getDataSet(path_coefficients);
+      const DataSet dataset_es = file.getDataSet(path_exponents);
+      const Attribute attr = dataset_cs.getAttribute("basisFormat");
+
+      // extract data from the datasets
+      dataset_cs.read(coefficients);
+      dataset_es.read(exponents);
+      attr.read(format);
+
+      // Move data to small vectors and keep appending or extending them as
+      // iteration over `dset_names` continues
+      libint2::svector<double> small_exp_1d;
+      std::move(exponents.begin(), exponents.end(), std::back_inserter(small_exp_1d));
+      small_exp.push_back(small_exp_1d);
+
+      for (const auto &v : coefficients) {
+        libint2::svector<double> small_coef_1d;
+        std::move(v.begin(), v.end(), std::back_inserter(small_coef_1d));
+        small_coef.push_back(small_coef_1d);
+      }
+
+      // The CP2K basis format is defined by a vector of integers, for each atom.
+      // For example For the C atom and the Basis DZVP-MOLOPT-GTH the basis format
+      // is:
+      //  2 0 2 7 2 2 1
+      // where:
+      //   * 2 is the Principal quantum number
+      //   * 0 is the minimum angular momemtum l
+      //   * 2 is the maximum angular momentum l
+      //   * 7 is the number of total exponents
+      //   * 2 Contractions of the 0 + l_min (S) Gaussian Orbitals
+      //   * 2 Contractions of the 1 + l_min (P) Gaussian Orbitals
+      //   * 1 Contractions of the 2 + l_min (D) Gaussian Orbitals
+      //
+      // Note: Elements 4 and onwards define the number of contracted for each
+      // angular momentum quantum number (all prior elements are disgarded).
+      int l, i;
+      libint2::svector<CP2K_Contractions> small_fmt_1d;
+      for (i=4, l=format[1]; i != static_cast<int>(format.size()); i++, l++) {
+        int count = format[i];
+        small_fmt_1d.push_back({l, count});
+      }
+      small_fmt.push_back(small_fmt_1d);
+    }
   } catch (HighFive::Exception &err) {
     // catch and print any HDF5 error
     std::cerr << err.what() << std::endl;
   }
-
-  // Move data to small vector
-  libint2::svector<double> small_exponents;
-  std::move(exponents.begin(), exponents.end(),
-            std::back_inserter(small_exponents));
-
-  libint2::svector<libint2::svector<double>> small_coefficients;
-  for (const auto &v : coefficients) {
-    libint2::svector<double> small;
-    std::move(v.begin(), v.end(), std::back_inserter(small));
-    small_coefficients.push_back(small);
-  }
-
-  return CP2K_Basis_Atom{symbol, small_coefficients, small_exponents,
-                         read_basisFormat(format)};
+  return CP2K_Basis_Atom{symbol, small_coef, small_exp, small_fmt};
 }
 
 /**
@@ -362,7 +398,8 @@ std::vector<string> get_unique_symbols(const std::vector<Atom> &atoms) {
 
 std::unordered_map<string, CP2K_Basis_Atom>
 create_map_symbols_basis(const string &path_hdf5,
-                         const std::vector<Atom> &atoms, const string &basis) {
+                         const std::vector<Atom> &atoms,
+                         const string &basis) {
   // Function to generate a map from symbols to basis specification
 
   std::unordered_map<string, CP2K_Basis_Atom> dict;
@@ -380,32 +417,23 @@ create_map_symbols_basis(const string &path_hdf5,
  */
 libint2::svector<Shell> create_shells_for_atom(const CP2K_Basis_Atom &data,
                                                const Atom &atom) {
-  // The CP2K basis format is defined by a vector of integers, for each atom.
-  // For example For the C atom and the Basis DZVP-MOLOPT-GTH the basis format
-  // is:
-  //  2 0 2 7 2 2 1
-  // where:
-  //   * 2 is the Principal quantum number
-  //   * 0 is the minimum angular momemtum l
-  //   * 2 is the maximum angular momentum l
-  //   * 7 is the number of total exponents
-  //   * 2 Contractions of S Gaussian Orbitals
-  //   * 2 Contractions of P Gaussian Orbitals
-  //   * 1 Contraction of D Gaussian Orbital
-  // Note: From element 4 onwards are define the number of contracted for each
-  // quantum number.
-  libint2::svector<int> basis_format = data.basis_format;
   libint2::svector<Shell> shells;
+  libint2::svector<double> exponents;
+  libint2::svector<CP2K_Contractions> basis_format;
 
   int acc = 0;
-  for (int i = 0; i + 4 < static_cast<int>(basis_format.size()); i++) {
-    for (int j = 0; j < basis_format[i + 4]; j++) {
-      shells.push_back({data.exponents,
-                        {// compute integrals in sphericals
-                         {i, true, data.coefficients[acc]}},
-                        // Atomic Coordinates
-                        {{atom.x, atom.y, atom.z}}});
-      acc += 1;
+  for (int i = 0; i != static_cast<int>(data.exponents.size()); i++) {
+    exponents = data.exponents[i];
+    basis_format = data.basis_format[i];
+    for (auto contractions : basis_format) {
+      for (int j = 0; j < contractions.count; j++) {
+        shells.push_back({
+          exponents,
+          {{contractions.l, true, data.coefficients[acc]}},  // compute integrals in sphericals
+          {{atom.x, atom.y, atom.z}}  // Atomic Coordinates
+        });
+        acc += 1;
+      }
     }
   }
   return shells;
@@ -540,4 +568,10 @@ PYBIND11_MODULE(compute_integrals, m) {
 
   m.def("compute_integrals_multipole", &compute_integrals_multipole,
         py::return_value_policy::reference_internal);
+
+  m.def("get_thread_count", &get_thread_count,
+        py::return_value_policy::reference_internal);
+
+  m.def("get_thread_type", &get_thread_type,
+        py::return_value_policy::reference_internal);
 }
