@@ -3,8 +3,7 @@ import os
 import shutil
 import sys
 from os.path import join
-
-from qmflows.type_hints import PathLike
+from pathlib import Path
 
 from nanoqm.workflows.input_validation import process_input
 from nanoqm.workflows.workflow_ipr import workflow_ipr
@@ -12,7 +11,7 @@ from nanoqm.workflows.workflow_ipr import workflow_ipr
 from .utilsTest import PATH_TEST
 
 
-def test_workflow_IPR(tmp_path: PathLike) -> None:
+def test_workflow_IPR(tmp_path: Path) -> None:
     """Test the Inverse Participation Ratio workflow."""
     file_path = PATH_TEST / 'input_test_IPR.yml'
     config = process_input(file_path, 'ipr_calculation')
@@ -24,7 +23,5 @@ def test_workflow_IPR(tmp_path: PathLike) -> None:
     try:
         workflow_ipr(config)
         os.remove("IPR.txt")
-    except BaseException:
-        print("scratch_path: ", tmp_path)
-        print("Unexpected error:", sys.exc_info()[0])
-        raise
+    except Exception as ex:
+        raise AssertionError(f"Unxpected error for scratch_path {tmp_path!r}") from ex
